@@ -1,5 +1,5 @@
 package Bolts::Meta::Class::Trait::Bag;
-$Bolts::Meta::Class::Trait::Bag::VERSION = '0.142860';
+$Bolts::Meta::Class::Trait::Bag::VERSION = '0.142930';
 # ABSTRACT: Metaclass role for Bolts-built bags
 
 use Moose::Role;
@@ -8,6 +8,14 @@ use Safe::Isa;
 use Scalar::Util qw( reftype );
 
 
+has artifacts => (
+    is          => 'ro',
+    isa         => 'ArrayRef',
+    required    => 1,
+    default     => sub { [] },
+);
+
+
 has such_that_isa => (
     is          => 'rw',
     isa         => 'Moose::Meta::TypeConstraint',
@@ -121,7 +129,7 @@ Bolts::Meta::Class::Trait::Bag - Metaclass role for Bolts-built bags
 
 =head1 VERSION
 
-version 0.142860
+version 0.142930
 
 =head1 DESCRIPTION
 
@@ -129,6 +137,10 @@ While a bag may be any kind of object, this metaclass role on a bag provides som
 
 =head1 ATTRIBUTES
 
+=head2 artifacts
+
+These are the artifacts that have been added to this bag.
+
 =head2 such_that_isa
 
 This is a L<Moose::Meta::TypeConstraint> to apply to the L<Bolts::Artifact/isa_type> of all contained artifacts.
